@@ -1,4 +1,10 @@
+"""CLI interface argument parser"""
+
+
+# Standard library import
 import argparse
+
+# Local import
 from crontip.__version__ import __version__
 
 parser = argparse.ArgumentParser(
