@@ -1,3 +1,9 @@
+"""Operate the file
+including read, write and find the latest file,
+"""
+
+
+# Local application imports
 from crontip.linux_cmd import get_output
 
 
