@@ -1,3 +1,11 @@
+"""Define the functions that used for
+execute a command,
+get output from it,
+get the result from it(is error exist?)
+"""
+
+
+# Standard library imports
 import subprocess
 
 
@@ -21,16 +29,3 @@ def get_output(cmd: str):
     """
     output = subprocess.run(cmd, shell=True, capture_output=True, text=True)
     return output.stdout[:-1]
-
-
-def format_text(text):
-    """
-    Return a list of text.\n
-    Remove the empty line in the end.
-    """
-    text = text.split('\n')
-
-    if not text[-1]:
-        text.pop()
-
-    return text
